/// <reference types="express" />
import * as express from 'express';
import { Either } from 'fp-ts/lib/Either';
import * as t from 'io-ts';
import { TaskEither } from './helpers/TaskEither';
export declare const createValidatedRequestTypes: <Query, Session, Body>(types: ValidatedRequestTypes<Query, Session, Body>) => ValidatedRequestTypes<Query, Session, Body>;
export declare type ValidatedRequestTypes<Query, Session, Body> = {
    query: t.Type<Query>;
    session: t.Type<Session>;
    body: t.Type<Body>;
};
export declare type ValidatedRequest<Query, Session, Body> = {
    ip: string;
    query: Query;
    session: Session;
    body: Body;
};
export declare type ResponseHandler<Response> = ((req: express.Request, res: express.Response) => (response: Response) => void);
export declare type ValidatedRequestHandler<Query, Session, Body, ErrorResponse, SuccessResponse> = ((validatedReq: ValidatedRequest<Query, Session, Body>) => Either<ErrorResponse, SuccessResponse>);
export declare type wrapValidatedRequestHandler = (<Query, Session, Body, ErrorResponse, SuccessResponse>(args: {
    types: ValidatedRequestTypes<Query, Session, Body>;
    handler: ValidatedRequestHandler<Query, Session, Body, ErrorResponse, SuccessResponse>;
    errorResponseHandler: ResponseHandler<ErrorResponse>;
    successResponseHandler: ResponseHandler<SuccessResponse>;
    createValidationErrorsError: (validationErrors: t.ValidationError[]) => ErrorResponse;
}) => express.RequestHandler);
export declare const wrapValidatedRequestHandler: wrapValidatedRequestHandler;
export declare type AsyncValidatedRequestHandler<Query, Session, Body, ErrorResponse, SuccessResponse> = ((validatedReq: ValidatedRequest<Query, Session, Body>) => TaskEither<ErrorResponse, SuccessResponse>);
export declare type wrapAsyncValidatedRequestHandler = (<Query, Session, Body, ErrorResponse, SuccessResponse>(args: {
    types: ValidatedRequestTypes<Query, Session, Body>;
    handler: AsyncValidatedRequestHandler<Query, Session, Body, ErrorResponse, SuccessResponse>;
    errorResponseHandler: ResponseHandler<ErrorResponse>;
    successResponseHandler: ResponseHandler<SuccessResponse>;
    createValidationErrorsError: (validationErrors: t.ValidationError[]) => ErrorResponse;
}) => express.RequestHandler);
export declare const wrapAsyncValidatedRequestHandler: wrapAsyncValidatedRequestHandler;
