"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const task = require("fp-ts/lib/Task");
const t = require("io-ts");
const TaskEither_1 = require("./helpers/TaskEither");
const wrapAsyncRequestHandler = promiseFn => (req, res, next) => promiseFn(req, res).catch(next);
exports.createValidatedRequestTypes = (types) => types;
const validateReq = ({ req, types, createValidationErrorsError }) => t
    .validate({
    query: req.query,
    session: req.session,
    body: req.body,
}, t.interface({
    query: types.query,
    session: types.session,
    body: types.body,
}, 'request'))
    .mapLeft(createValidationErrorsError)
    .map(({ query, session, body }) => ({ ip: req.ip, query, session, body }));
exports.wrapValidatedRequestHandler = ({ types, errorResponseHandler, successResponseHandler, handler, createValidationErrorsError, }) => (req, res) => {
    validateReq({ req, types, createValidationErrorsError })
        .chain(handler)
        .fold(errorResponseHandler(req, res), successResponseHandler(req, res));
};
exports.wrapAsyncValidatedRequestHandler = ({ types, errorResponseHandler, successResponseHandler, handler, createValidationErrorsError, }) => wrapAsyncRequestHandler((req, res) => new TaskEither_1.TaskEither(task.of(validateReq({ req, types, createValidationErrorsError })))
    .chain(handler)
    .fold(errorResponseHandler(req, res), successResponseHandler(req, res))
    .run());
//# sourceMappingURL=index.js.map